reqs tool
=========

Find all packages imported by your modules.

Modifications
-------------

This tool will parse all your python files (modules) without importing them and
report on screen the packages that you require.

Quick tutorial
--------------

Just call the tool at the root of your package without any option::

    (dvlpt)$ pmg reqs

